@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-11'; # DATE
+our $DATE = '2022-12-16'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module name (e.g. Foo::Bar) or prefix (e.g. Foo::Bar::)',
@@ -56,7 +56,7 @@ Sah::Schema::perl::modname_or_prefix - Perl module name (e.g. Foo::Bar) or prefi
 
 =head1 VERSION
 
-This document describes version 0.045 of Sah::Schema::perl::modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
+This document describes version 0.046 of Sah::Schema::perl::modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2022-12-16.
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "Foo::Bar::";
+ $data = "Foo-Bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -109,8 +109,8 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "Foo::Bar::";
- my $res = $validator->($data); # => ["","Foo::Bar::"]
+ $data = "Foo-Bar";
+ my $res = $validator->($data); # => ["","Foo::Bar"]
  
  # a sample invalid data
  $data = "Foo|Bar";
@@ -177,6 +177,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'PerlModnameOrPrefix')
+     );
+ }
+
+ use My::Types qw(PerlModnameOrPrefix);
+ PerlModnameOrPrefix->assert_valid($data);
+
 =head1 DESCRIPTION
 
 Contains coercion rule so inputing C<Foo-Bar> or C<Foo/Bar> will be normalized to
