@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-11'; # DATE
+our $DATE = '2022-12-16'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module name with version number suffix, e.g. Foo::Bar@0.001',
@@ -46,7 +46,7 @@ Sah::Schema::perl::modname_with_ver - Perl module name with version number suffi
 
 =head1 VERSION
 
-This document describes version 0.045 of Sah::Schema::perl::modname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
+This document describes version 0.046 of Sah::Schema::perl::modname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2022-12-16.
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "Foo::Bar\@a";
+ $data = "Foo-Bar";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -103,8 +103,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["","Foo::Bar\@1.0.0"]
  
  # a sample invalid data
- $data = "Foo::Bar\@a";
- my $res = $validator->($data); # => ["Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z","Foo::Bar\@a"]
+ $data = "Foo-Bar";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z","Foo::Bar"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -167,6 +167,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'PerlModnameWithVer')
+     );
+ }
+
+ use My::Types qw(PerlModnameWithVer);
+ PerlModnameWithVer->assert_valid($data);
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Perl>.
