@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-11'; # DATE
+our $DATE = '2022-12-16'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of Perl module names, e.g. ["Foo::Bar", "Baz"]',
@@ -53,7 +53,7 @@ Sah::Schema::perl::modnames - Array of Perl module names, e.g. ["Foo::Bar", "Baz
 
 =head1 VERSION
 
-This document describes version 0.045 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
+This document describes version 0.046 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2022-12-16.
 
 =head1 SYNOPSIS
 
@@ -140,6 +140,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'PerlModnames')
+     );
+ }
+
+ use My::Types qw(PerlModnames);
+ PerlModnames->assert_valid($data);
+
 =head1 DESCRIPTION
 
 Array of Perl module names, where each element is of C<perl::modname> schema,
