@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-11'; # DATE
+our $DATE = '2022-12-16'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module prefix, e.g. Foo::Bar::',
@@ -64,7 +64,7 @@ Sah::Schema::perl::modprefix - Perl module prefix, e.g. Foo::Bar::
 
 =head1 VERSION
 
-This document describes version 0.045 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
+This document describes version 0.046 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2022-12-16.
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "Foo-";
+ $data = "";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -119,8 +119,8 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "Foo-";
- my $res = $validator->($data); # => ["","Foo::"]
+ $data = "";
+ my $res = $validator->($data); # => ["",""]
  
  # a sample invalid data
  $data = "::";
@@ -187,6 +187,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'PerlModprefix')
+     );
+ }
+
+ use My::Types qw(PerlModprefix);
+ PerlModprefix->assert_valid($data);
+
 =head1 DESCRIPTION
 
 Perl module prefix, e.g. C<Foo::Bar::>. An empty prefix ('') is also allowed.
