@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-11'; # DATE
+our $DATE = '2022-12-16'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 our $schema = [array => {
     summary => 'Perl module prefixes, e.g. ["", "Foo::", "Foo::Bar::"]',
@@ -54,7 +54,7 @@ Sah::Schema::perl::modprefixes - Perl module prefixes, e.g. ["", "Foo::", "Foo::
 
 =head1 VERSION
 
-This document describes version 0.045 of Sah::Schema::perl::modprefixes (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
+This document describes version 0.046 of Sah::Schema::perl::modprefixes (from Perl distribution Sah-Schemas-Perl), released on 2022-12-16.
 
 =head1 SYNOPSIS
 
@@ -141,6 +141,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema:
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('$sch_name*', name=>'PerlModprefixes')
+     );
+ }
+
+ use My::Types qw(PerlModprefixes);
+ PerlModprefixes->assert_valid($data);
+
 =head1 DESCRIPTION
 
 Array of Perl module prefixes, where each element is of C<perl::modprefix>
